==> spip_3.2.11.orig.tar.xz: plugins-dist/revisions/lang/revisions_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=de
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// B
	'bouton_comparer' => 'Unterschiede anzeigen',

	// D
	'diff_para_ajoute' => 'Neuer Absatz',
	'diff_para_deplace' => 'Absatz verschoben',
	'diff_para_supprime' => 'Absatz gelöscht',
	'diff_texte_ajoute' => 'Neuer Text',
	'diff_texte_deplace' => 'Text verschoben',
	'diff_texte_supprime' => 'Text gelöscht',
	'differences_versions' => 'Unterschiede zwischen VersionN<sup>o</sup>@id_version@ und Version N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Version N<sup>o</sup>@version@ wiederherstellen',
	'icone_suivi_revisions' => 'Versionskontrolle',
	'info_1_revision' => '1 Version',
	'info_aucune_revision' => 'Keine Versionen',
	'info_historique' => 'Versionen:',
	'info_historique_lien' => 'Versionen anzeigen',
	'info_historique_titre' => 'Versionskontrolle',
	'info_nb_revisions' => '@nb@ Versionen',

	// L
	'label_choisir_id_version' => 'Wählen sie die zu vergleichenden Versionen',
	'label_config_revisions_objets' => 'Versionskontrolle für:',

	// M
	'message_valider_recuperer_version' => 'Bestätigen um zu dieser Version zurückzukehren.',

	// O
	'objet_editorial' => 'Objekt',

	// P
	'plugin_update' => 'Update des Plugins "Versionskontrolle" auf Version @version@.',

	// T
	'titre_form_revisions_objets' => 'Versionskontrolle aktivieren',
	'titre_restaurer_version' => 'Version wiederherstellen',
	'titre_revisions' => 'Versionen',

	// V
	'version_deplace_rubrique' => 'Verschoben von <b>« @from@ »</b> nach <b>« @to@ »</b>.',
	'version_initiale' => 'Ursprüngliche Fassung',
	'voir_differences' => 'Unterschiede anzeigen',
	'voir_mes_revisions' => 'Meine Versionen',
	'voir_revisions' => 'Versionen anzeigen  (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'Alle Versionen'
);

==> spip_4.4.3+dfsg.orig.tar.xz: plugins-dist/revisions/lang/revisions_de.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/revisions?lang_cible=de
// ** ne pas modifier le fichier **

return [

	// B
	'bouton_comparer' => 'Unterschiede anzeigen',

	// D
	'diff_para_ajoute' => 'Neuer Absatz',
	'diff_para_deplace' => 'Absatz verschoben',
	'diff_para_supprime' => 'Absatz gelöscht',
	'diff_texte_ajoute' => 'Neuer Text',
	'diff_texte_deplace' => 'Text verschoben',
	'diff_texte_supprime' => 'Text gelöscht',
	'differences_versions' => 'Unterschiede zwischen VersionN<sup>o</sup>@id_version@ und Version N<sup>o</sup>@id_diff@',

	// I
	'icone_restaurer_version' => 'Version N<sup>o</sup>@version@ wiederherstellen',
	'icone_suivi_revisions' => 'Versionskontrolle',
	'info_1_revision' => '1 Version',
	'info_aucune_revision' => 'Keine Versionen',
	'info_historique' => 'Versionen:',
	'info_historique_lien' => 'Versionen anzeigen',
	'info_historique_titre' => 'Versionskontrolle',
	'info_nb_revisions' => '@nb@ Versionen',

	// L
	'label_choisir_id_version' => 'Wählen sie die zu vergleichenden Versionen',
	'label_config_revisions_objets' => 'Versionskontrolle für:',

	// M
	'message_valider_recuperer_version' => 'Bestätigen um zu dieser Version zurückzukehren.',

	// O
	'objet_editorial' => 'Objekt',

	// P
	'plugin_update' => 'Update des Plugins "Versionskontrolle" auf Version @version@.',

	// T
	'titre_form_revisions_objets' => 'Versionskontrolle aktivieren',
	'titre_restaurer_version' => 'Version wiederherstellen',
	'titre_revisions' => 'Versionen',

	// V
	'version_deplace_rubrique' => 'Verschoben von <b>« @from@ »</b> nach <b>« @to@ »</b>.',
	'version_initiale' => 'Ursprüngliche Fassung',
	'voir_differences' => 'Unterschiede anzeigen',
	'voir_mes_revisions' => 'Meine Versionen',
	'voir_revisions' => 'Versionen anzeigen  (@objet@ @id_objet@: @titre@)',
	'voir_toutes_les_revisions' => 'Alle Versionen',
];
